@@ -15,6 +15,15 @@ from os.path import join, normpath, isfile
 from cbm.utils import config
 
 
+def get_options(debug=False):
+    api_url, api_user, api_pass = config.credentials('api')
+    requrl = """{}/query/info"""
+    response = requests.get(requrl.format(api_url), auth=(api_user, api_pass))
+    if debug:
+        print(requrl.format(api_url), response)
+    return response.content
+
+
 def parcel_by_loc(aoi, year, lon, lat, ptype=None,
                   geom=False, wgs84=False, debug=False):
 
@@ -26,7 +35,7 @@ def parcel_by_loc(aoi, year, lon, lat, ptype=None,
         requrl = f"{requrl}&ptype={ptype}"
     if wgs84 is True:
         requrl = f"{requrl}&wgs84={wgs84}"
-    # print(requrl.format(api_url, aoi, year, pid))
+    # print(requrl.format(api_url, aoi, year, lon, lat))
     response = requests.get(requrl.format(api_url, aoi, year, lon, lat),
                             auth=(api_user, api_pass))
     if debug:
@@ -37,7 +46,7 @@ def parcel_by_loc(aoi, year, lon, lat, ptype=None,
 def parcel_by_id(aoi, year, pid, ptype=None, geom=False,
                  wgs84=False, debug=False):
     api_url, api_user, api_pass = config.credentials('api')
-    requrl = """{}/query/parcelById?aoi={}&year={}&pid={}"""
+    requrl = """{}/query/parcelByID?aoi={}&year={}&pid={}"""
     if geom is True:
         requrl = f"{requrl}&withGeometry=True"
     if ptype not in [None, '']:
@@ -72,6 +81,20 @@ def parcel_by_polygon(aoi, year, polygon, ptype=None, geom=False,
     return response.content
 
 
+def parcel_peers(aoi, year, pid, distance=1000.0,
+                 maxPeers=10, ptype=None, debug=False):
+    api_url, api_user, api_pass = config.credentials('api')
+    requrl = """{}/query/parcelPeers?aoi={}&year={}&pid={}&distance={}&max={}"""
+    if ptype not in [None, '']:
+        requrl = f"{requrl}&ptype={ptype}"
+    response = requests.get(requrl.format(api_url, aoi, year, pid, distance,
+                                          maxPeers), auth=(api_user, api_pass))
+    if debug:
+        print(requrl.format(api_url, aoi, year, pid, distance, maxPeers),
+              response)
+    return response.content
+
+
 def parcel_ts(aoi, year, pid, tstype='s2', ptype=None, band='', debug=False):
 
     api_url, api_user, api_pass = config.credentials('api')
@@ -106,7 +129,7 @@ def cbl(lon, lat, start_date, end_date, bands=None, lut=None, chipsize=None):
 
 
 def rcbl(parcel, start_date, end_date, bands, chipsize, filespath,
-         quiet=True):
+         debug=False):
     """Get parcel raw chip images from RESTful API by location"""
     import os
     import os.path
@@ -149,7 +172,7 @@ def rcbl(parcel, start_date, end_date, bands, chipsize, filespath,
         response = requests.get(requrl.format(api_url, cen_y, cen_x, start_date,
                                               end_date, band, chipsize),
                                 auth=(api_user, api_pass))
-        if not quiet:
+        if debug:
             print("Request url:", requrl.format(
                 api_url, cen_y, cen_x, start_date, end_date, band, chipsize))
             print("Geom:", geom)
@@ -169,83 +192,22 @@ def rcbl(parcel, start_date, end_date, bands, chipsize, filespath,
             outf = normpath(join(filespath, c.split('/')[-1]))
             if not isfile(outf):
                 res = requests.get(url, stream=True)
-                if not quiet:
+                if debug:
                     print(f"Downloading {c.split('/')[-1]}")
                 with open(outf, "wb") as handle:
                     for chunk in res.iter_content(chunk_size=512):
                         if chunk:  # filter out keep-alive new chunks
                             handle.write(chunk)
-        if not quiet:
+        if debug:
             print(
                 f"Images for band '{band}', for the selected dates are downloaded.")
 
-    if not quiet:
+    if debug:
         print("\n------Total time------")
         print(
             f"Total time required for {len(bands)} bands: {time.time() - start} seconds.")
 
 
-def clouds(geom):
-    import glob
-    import json
-    import rasterio
-    from osgeo import osr
-    from rasterstats import zonal_stats
-    # Check whether our parcel is cloud free
-
-    # We should have a list of GeoTIFFs ending with .SCL.tif
-    tiflist = glob.glob('*.SCL.tif')
-
-    for t in tiflist:
-        with rasterio.open(t) as src:
-            affine = src.transform
-            CRS = src.crs
-            data = src.read(1)
-
-        # Reproject the parcel geometry in the image crs
-        imageCRS = int(str(CRS).split(':')[-1])
-
-        # Cross check with the projection of the geometry
-        # This needs to be done for each image, because the parcel could be in
-        # a straddle between (UTM) zones
-        geomCRS = int(geom.GetSpatialReference().GetAuthorityCode(None))
-
-        if geomCRS != imageCRS:
-            target = osr.SpatialReference()
-            target.ImportFromEPSG(imageCRS)
-            source = osr.SpatialReference()
-            source.ImportFromEPSG(geomCRS)
-            transform = osr.CoordinateTransformation(source, target)
-            geom.Transform(transform)
-
-        # Format as a feature collection (with only 1 feature)
-        # and extract the histogram
-        features = {"type": "FeatureCollection",
-                    "features": [{"type": "feature",
-                                  "geometry": json.loads(geom.ExportToJson()),
-                                  "properties": {"pid": pid}}]}
-        zs = zonal_stats(features, data, affine=affine, prefix="",
-                         nodata=0, categorical=True, geojson_out=True)
-
-        # This has only one record
-        properties = zs[0].get('properties')
-
-        # pid was used as a dummy key to make sure the histogram
-        # values are in 'properties'
-        del properties['pid']
-
-        histogram = {int(float(k)): v for k, v in properties.items()}
-        # print(t, histogram)
-
-
-def get_options():
-    api_url, api_user, api_pass = config.credentials('api')
-    requrl = """{}/query/options"""
-    response = requests.get(requrl.format(api_url),
-                            auth=(api_user, api_pass))
-    return response.content
-
-
 def background(lon, lat, chipsize=512, extend=512, tms='Google',
                bg_path='', debug=False):
     # aoi='undefined', year='', pid='0000', quiet=True):
@@ -267,9 +229,9 @@ def background(lon, lat, chipsize=512, extend=512, tms='Google',
 
     # The url to get the background image
     requrl = f"lon={lon}&lat={lat}&chipsize={chipsize}&extend={extend}"
-    # print(f"{api_url}/query/backgroundByLocation?{requrl}&tms={tms}&raw")
+    # print(f"{api_url}/query/backgroundByLocation?{requrl}&tms={tms}&iformat=tif")
     response = requests.get(
-        f"{api_url}/query/backgroundByLocation?{requrl}&tms={tms}&raw",
+        f"{api_url}/query/backgroundByLocation?{requrl}&tms={tms}&iformat=tif",
         auth=(api_user, api_pass))
     # print(response)
 
@@ -281,12 +243,12 @@ def background(lon, lat, chipsize=512, extend=512, tms='Google',
             if debug:
                 print("Image not found...")
                 print(
-                    f"{api_url}/query/backgroundByLocation?{requrl}&tms={tms}&raw", response)
+                    f"{api_url}/query/backgroundByLocation?{requrl}&tms={tms}&iformat=tif", response)
             return response
         else:
             if debug:
                 print(
-                    f"{api_url}/query/backgroundByLocation?{requrl}&tms={tms}&raw", response)
+                    f"{api_url}/query/backgroundByLocation?{requrl}&tms={tms}&iformat=tif", response)
             res = requests.get(img_url, stream=True)
             image_name = img_url.split('/')[-1].lower()
             bg_file = normpath(join(bg_path, image_name))
