@@ -41,26 +41,15 @@ def ndvi(aoi, year, pids, ptype=None, scl='3_8_9_10_11', std=True,
 
     crop_names = []
     for pid in pids:
-        pid = str(pid)
         path = normpath(join(config.get_value(['paths', 'temp']),
                              aoi, str(year), str(pid)))
         file_info = normpath(join(path, 'info.json'))
         if not isfile(file_info):
-            parcel_info.by_pid(aoi, year, pid)
+            parcel_info.by_pid(aoi, str(year), str(pid), ptype, True)
         with open(file_info, 'r') as f:
             info_data = json.loads(f.read())
         crop_names.append(info_data['cropname'][0])
-
-    parcel_peers = True
-    if len(pids) == 1:
-        plot_title = f"NDVI profile for parcel '{pids[0]}', crop type: {crop_names[0]}."
-        cloudfreelabel = "Cloud free"
-    elif all_equal(crop_names):
-        plot_title = f"NDVI profiles for crop type: {crop_names[0]}."
-        cloudfreelabel = pid  # , area: {area:.1f}sqm"
-    else:
-        plot_title = "NDVI profiles"
-        parcel_peers = False
+    parcel_peers = all_equal(crop_names)
 
     fig = plt.figure(figsize=(16.0, 10.0))
     axb = fig.add_subplot(1, 1, 1)
@@ -68,10 +57,8 @@ def ndvi(aoi, year, pids, ptype=None, scl='3_8_9_10_11', std=True,
     pcount = 1
 
     for pid in pids:
-        pid = str(pid)
         path = normpath(join(config.get_value(['paths', 'temp']),
                              aoi, str(year), str(pid)))
-
         file_info = normpath(join(path, 'info.json'))
         with open(file_info, 'r') as f:
             info_data = json.loads(f.read())
@@ -79,9 +66,20 @@ def ndvi(aoi, year, pids, ptype=None, scl='3_8_9_10_11', std=True,
         crop_name = info_data['cropname'][0]
         area = info_data['area'][0]
 
+        if len(pids) == 1:
+            plot_title = f"NDVI profile for parcel '{pid}', crop type: {crop_names[0]}."
+            cloudfreelabel = "Cloud free"
+        elif parcel_peers:
+            plot_title = f"NDVI profiles for crop type: {crop_names[0]}."
+            cloudfreelabel = pid  # , area: {area:.1f}sqm"
+        else:
+            plot_title = "NDVI profiles"
+            cloudfreelabel = f"{pid}, {crop_name}"
+
         file_ts = normpath(join(path, 'time_series_s2.csv'))
         if not isfile(file_ts):
-            time_series.by_pid(aoi, year, pid, 's2', ptype, '', debug)
+            time_series.by_pid(aoi, str(year), str(pid),
+                               's2', ptype, '', debug)
         df = pd.read_csv(file_ts, index_col=0)
 
         df['date'] = pd.to_datetime(df['date_part'], unit='s')
@@ -117,9 +115,6 @@ def ndvi(aoi, year, pids, ptype=None, scl='3_8_9_10_11', std=True,
                      markersize=10, color='lightgray',
                      fillstyle='none', label='All observations')
 
-        if not parcel_peers:
-            cloudfreelabel = f"{pid}, {crop_name}"
-
         if 'hist' in df.columns:
             df['cf'] = pd.Series(dtype='str')
             scls = scl.split('_')
@@ -141,16 +136,19 @@ def ndvi(aoi, year, pids, ptype=None, scl='3_8_9_10_11', std=True,
                 axb.plot(dfNDVI[cloudfree].index, dfNDVI[cloudfree],
                          linestyle='--', marker='P', markersize=10,
                          fillstyle='none', label=cloudfreelabel)
-                pcount += 1
                 if errorbar:
                     axb.errorbar(dfNDVI[cloudfree].index, dfNDVI[cloudfree],
                                  cloufreestd, fmt=' ', color='Gray',
-                                 linewidth=2, capsize=4, alpha=0.5)
+                                 linewidth=2, capsize=4, alpha=0.4)
             if std:
+                if max_line_plots == 1 and pcount == 1:
+                    peers_lable = 'Parcel peers'
+                else:
+                    peers_lable = None
                 axb.fill_between(dfNDVI[cloudfree].index,
                                  dfNDVI[cloudfree] - cloufreestd,
                                  dfNDVI[cloudfree] + cloufreestd,
-                                 color='b', alpha=0.03)
+                                 color='b', alpha=0.05, label=peers_lable)
         except Exception as err:
             message = f"Could not mark cloud free images: {err}"
 
@@ -158,6 +156,7 @@ def ndvi(aoi, year, pids, ptype=None, scl='3_8_9_10_11', std=True,
         axb.set_ylim(0, 1.0)
 
         axb.legend(frameon=False)
+        pcount += 1
     if 'message' in locals():
         print(message)
     axb.set_title(plot_title)
@@ -165,8 +164,8 @@ def ndvi(aoi, year, pids, ptype=None, scl='3_8_9_10_11', std=True,
     return plt.show()
 
 
-def s2(aoi, year, pid, ptype=None, bands=['B08'], scl='3_8_9_10_11',
-       debug=False):
+def s2(aoi, year, pid, ptype=None, bands=['B02', 'B03', 'B04', 'B08'],
+       scl='3_8_9_10_11', debug=False):
     if type(bands) is str:
         bands = [bands]
     path = normpath(join(config.get_value(['paths', 'temp']),
@@ -174,7 +173,7 @@ def s2(aoi, year, pid, ptype=None, bands=['B08'], scl='3_8_9_10_11',
 
     parcel_file = normpath(join(path, 'info.json'))
     if not isfile(parcel_file):
-        parcel_info.by_pid(aoi, year, pid, ptype, True)
+        parcel_info.by_pid(aoi, str(year), str(pid), ptype, True)
     with open(parcel_file, 'r') as f:
         parcel = json.loads(f.read())
 
@@ -183,7 +182,7 @@ def s2(aoi, year, pid, ptype=None, bands=['B08'], scl='3_8_9_10_11',
 
     file_ts = normpath(join(path, 'time_series_s2.csv'))
     if not isfile(file_ts):
-        time_series.by_pid(aoi, year, pid, 's2', ptype, '', debug)
+        time_series.by_pid(aoi, str(year), str(pid), 's2', ptype, '', debug)
     df = pd.read_csv(file_ts, index_col=0)
 
     df['date'] = pd.to_datetime(df['date_part'], unit='s')
@@ -281,27 +280,28 @@ def s2(aoi, year, pid, ptype=None, bands=['B08'], scl='3_8_9_10_11',
     return plt.show()
 
 
-def s1_bs(aoi, year, pid, ptype=None, debug=False):
+def s1(aoi, year, pid, tstype='bs', ptype=None, debug=False):
     path = normpath(join(config.get_value(['paths', 'temp']),
                          aoi, str(year), str(pid)))
     file_info = normpath(join(path, 'info.json'))
     if not isfile(file_info):
-        parcel_info.by_pid(aoi, year, pid, ptype, True)
+        parcel_info.by_pid(aoi, str(year), str(pid), ptype, True)
     with open(file_info, 'r') as f:
         info_data = json.loads(f.read())
 
     crop_name = info_data['cropname'][0]
     area = info_data['area'][0]
 
-    file_ts = normpath(join(path, 'time_series_bs.csv'))
+    file_ts = normpath(join(path, f'time_series_{tstype}.csv'))
     if not isfile(file_ts):
-        time_series.by_pid(aoi, year, pid, 'bs', ptype, '', debug)
+        time_series.by_pid(aoi, str(year), str(pid), tstype, ptype, '', debug)
     df = pd.read_csv(file_ts, index_col=0)
 
     df['date'] = pd.to_datetime(df['date_part'], unit='s')
     start_date = df.iloc[0]['date'].date()
     end_date = df.iloc[-1]['date'].date()
-    # print(f"From '{start_date}' to '{end_date}'.")
+    if debug:
+        print(f"From '{start_date}' to '{end_date}'.")
 
     pd.set_option('max_colwidth', 200)
     pd.set_option('display.max_columns', 20)
@@ -317,92 +317,43 @@ def s1_bs(aoi, year, pid, ptype=None, debug=False):
     datesFmt = mdates.DateFormatter('%-d %b %Y')
 
     # Plot Backscattering coefficient
-    datesFmt = mdates.DateFormatter('%-d %b %Y')
     df = df[df['mean'] >= 0]  # to remove negative values
 
-    dfVV = df[df.band == 'VVb'].copy()
-    dfVH = df[df.band == 'VHb'].copy()
+    dfVV = df[df.band == f'VV{tstype[0]}'].copy()
+    dfVH = df[df.band == f'VH{tstype[0]}'].copy()
     fig = plt.figure(figsize=(16.0, 10.0))
-    axb = fig.add_subplot(1, 1, 1)
+    ax = fig.add_subplot(1, 1, 1)
 
-    dfVV['mean'] = dfVV['mean'].map(lambda s: 10.0 * np.log10(s))
-    dfVH['mean'] = dfVH['mean'].map(lambda s: 10.0 * np.log10(s))
+    if tstype == 'bs':
+        dfVV['mean'] = dfVV['mean'].map(lambda s: 10.0 * np.log10(s))
+        dfVH['mean'] = dfVH['mean'].map(lambda s: 10.0 * np.log10(s))
+        ax.set_ylim(-25, -5)
+        # dfVV['p25'] = dfVV['p25'].map(lambda s: 10.0 * np.log10(s))
+        # dfVV['p75'] = dfVV['p75'].map(lambda s: 10.0 * np.log10(s))
+        # dfVH['p25'] = dfVH['p25'].map(lambda s: 10.0 * np.log10(s))
+        # dfVH['p75'] = dfVH['p75'].map(lambda s: 10.0 * np.log10(s))
+        # ax.fill_between(dfVV.index, dfVV['p25'],
+        #                 dfVV['p75'], color='b', alpha=0.1)
+        # ax.fill_between(dfVH.index, dfVH['p25'],
+        #                 dfVH['p75'], color='b', alpha=0.1)
+        ylabel = 'Sentinel-1 Backscattering coefficient, $\gamma\degree$ (dB)'
+    else:
+        ax.set_ylim(0, 1)
+        ylabel = 'Sentinel-1 6 day coherence'
 
-    axb.set_title(
-        f"Parcel {pid} (crop: {crop_name}, area: {area:.2f} sqm)")
-    axb.set_xlabel("Date")
-    axb.xaxis.set_major_formatter(datesFmt)
+    ax.set_title(
+        f"Parcel {pid} (crop: {crop_name}, area: {area:.1f} sqm)")
+    ax.set_xlabel("Date")
+    ax.xaxis.set_major_formatter(datesFmt)
 
-    axb.set_ylabel(r'Backscattering coefficient, $\gamma\degree$ (dB)')
-    axb.plot(dfVH.index, dfVH['mean'], linestyle=' ', marker='s',
-             markersize=10, color='DarkBlue', fillstyle='none', label='VH')
-    axb.plot(dfVV.index, dfVV['mean'], linestyle=' ', marker='o',
-             markersize=10, color='Red', fillstyle='none', label='VV')
+    ax.set_ylabel(ylabel)
+    ax.plot(dfVH.index, dfVH['mean'], linestyle=' ', marker='.',
+            markersize=10, color='DarkBlue', label='VH')
+    ax.plot(dfVV.index, dfVV['mean'], linestyle=' ', marker='.',
+            markersize=10, color='Red', label='VV')
 
-    axb.set_xlim(start_date, end_date + timedelta(1))
-    axb.set_ylim(-25, 0)
+    ax.set_xlim(start_date, end_date + timedelta(1))
 
-    axb.legend(frameon=False)  # loc=2)
-
-    return plt.show()
-
-
-def s1_c6(aoi, year, pid, ptype=None, debug=False):
-    path = normpath(join(config.get_value(['paths', 'temp']),
-                         aoi, year, str(pid)))
-    file_info = normpath(join(path, 'info.json'))
-    if not isfile(file_info):
-        parcel_info.by_pid(aoi, year, pid, ptype, True)
-    with open(file_info, 'r') as f:
-        info_data = json.loads(f.read())
-
-    crop_name = info_data['cropname'][0]
-    area = info_data['area'][0]
-
-    file_ts = normpath(join(path, 'time_series_c6.csv'))
-    if not isfile(file_ts):
-        time_series.by_pid(aoi, year, pid, 'c6', ptype, '', debug)
-    df = pd.read_csv(file_ts, index_col=0)
-
-    df['date'] = pd.to_datetime(df['date_part'], unit='s')
-    start_date = df.iloc[0]['date'].date()
-    end_date = df.iloc[-1]['date'].date()
-    # print(f"From '{start_date}' to '{end_date}'.")
-
-    pd.set_option('max_colwidth', 200)
-    pd.set_option('display.max_columns', 20)
-    datesFmt = mdates.DateFormatter('%-d %b %Y')
-
-    # Plot settings are confirm IJRS graphics instructions
-    plt.rcParams['axes.titlesize'] = 16
-    plt.rcParams['axes.labelsize'] = 14
-    plt.rcParams['xtick.labelsize'] = 12
-    plt.rcParams['ytick.labelsize'] = 12
-    plt.rcParams['legend.fontsize'] = 14
-
-    df.set_index(['date'], inplace=True)
-
-    # Plot Coherence
-
-    dfVV = df[df.band == 'VVc'].copy()
-    dfVH = df[df.band == 'VHc'].copy()
-    fig = plt.figure(figsize=(16.0, 10.0))
-    axb = fig.add_subplot(1, 1, 1)
-
-    axb.set_title(
-        f"Parcel {pid} (crop: {crop_name}, area: {area:.2f} sqm)")
-    axb.set_xlabel("Date")
-    axb.xaxis.set_major_formatter(datesFmt)
-
-    axb.set_ylabel(r'Coherence')
-    axb.plot(dfVH.index, dfVH['mean'], linestyle=' ', marker='s',
-             markersize=10, color='DarkBlue', fillstyle='none', label='VH')
-    axb.plot(dfVV.index, dfVV['mean'], linestyle=' ', marker='o',
-             markersize=10, color='Red', fillstyle='none', label='VV')
-
-    axb.set_xlim(start_date, end_date + timedelta(1))
-    axb.set_ylim(0, 1)
-
-    axb.legend(frameon=False)  # loc=2)
+    ax.legend(frameon=False)  # loc=2)
 
     return plt.show()
